@@ -181,8 +181,9 @@ class WaitingOn:
         self._waiting_on = set()
 
     def add(self, socket: "BaseSocket") -> None:
-        if socket._name not in self._waiting_on:
-            self._waiting_on.add(socket._name)
+        """Add a socket to the waiting list."""
+        if socket._node.name not in self._waiting_on:
+            self._waiting_on.add(socket._node.name)
             self.parent._graph.add_link(
                 socket._node.outputs._wait, self.parent._node.inputs._wait
             )
@@ -287,6 +288,9 @@ class BaseSocket:
             type (str, optional): Socket type. Defaults to "INPUT".
             link_limit (int, optional): Maximum number of links. Defaults to 1.
         """
+        from node_graph.utils import valid_name_string
+
+        valid_name_string(name)
         self._name = name
         self._node = node
         self._parent = parent
@@ -667,7 +671,9 @@ class NodeSocketNamespace(BaseSocket, OperatorSocketMixin):
             for key, val in value.items():
                 if key not in self:
                     if self._metadata.dynamic:
-                        if isinstance(val, dict):
+                        if isinstance(val, dict) or isinstance(
+                            val, NodeSocketNamespace
+                        ):
                             self._new(
                                 self._SocketPool["namespace"],
                                 key,
